@@ -4,7 +4,7 @@ module make_init
   use gtool_history
   use Derivation
   use Algebra
-  use Alge_Solv
+  use Ellip_Slv
   use Phys_Const
   use val_define
   use read_namelist
@@ -63,7 +63,7 @@ subroutine make_initialize()
         end do
      end do
 
-     call Poisson_Jacobi( x, y, pois_force, eps, boundary, psi_old,  &
+     call Ellip_Jacobi_2d( x, y, pois_force, eps, boundary, psi_old,  &
   &                       bndp, undef=undef, inner_bound=ibp )
 
   end if
