@@ -10,13 +10,14 @@ subroutine read_name()
 
   use val_define
 
-  namelist /input /nr, nz, nt, rmin, zmin, dr, dz, dt, dmpstp,  &
+  namelist /input /nr, nz, nt, rmin, zmin, dr, dz, dtb, dts, dmpstp,  &
   &                foname, time_flag, coril, zsp, SPG_coe, tau_R, lo,  &
-  &                fallv, qt_thres, cg, CD0
-  read(5,nml=input)
+  &                fallv, qt_thres, cg, CD0, Ts, alpha, beta, nunh, nunv
 
   namelist /init_set /nri, nzi, rimin, zimin, dri, dzi, sname, finame,  &
-  &                   sst, undef, zlim, vvmax, rvmax
+  &                   sst, undef, zlim, vvmax, rvmax, rord, sfact
+
+  read(5,nml=input)
   read(5,nml=init_set)
 
 end subroutine
