@@ -48,6 +48,7 @@ program sound_1d
   integer :: nnz  ! ǡޤȤ˻Ȥΰˤ
   integer :: nx  ! ǡο
   integer :: IWS
+  integer :: cape_opt  ! CAPE ׻κ, LNB ǡüξ.
   integer, parameter :: fig_num=3  ! ޤμ
   integer, dimension(11) :: col_num  ! ۥɥչ
 
@@ -69,8 +70,8 @@ program sound_1d
 
 !-- namelist file ɤ߹
 
-  namelist /input /z_ref, p_ref, list_name, dmp_flag, undef, draw_flag,  &
-  &                draw_region_p, draw_region_z, IWS, unit_v,  &
+  namelist /input /z_ref, p_ref, cape_opt, list_name, dmp_flag, undef,  &
+  &                draw_flag, draw_region_p, draw_region_z, IWS, unit_v,  &
   &                sysfont
   read(5,nml=input)
 
@@ -220,7 +221,7 @@ program sound_1d
 
 !-- ή԰ѥ᡼׻
 !-- 1. CAPE ׻
-     cape_c=CAPE( pres, height, qv, temp, z_ref, undeff=undef )!, opt=2 )
+     cape_c=CAPE( pres, height, qv, temp, z_ref, undeff=undef, copt=cape_opt )!, opt=2 )
 !     write(*,*) "MESSAGE : CAPE option is 2."
 
 !-- 2. CIN ׻
@@ -349,8 +350,9 @@ program sound_1d
 
      if(draw_flag(2:2)=='o')then
         call DclSetParm( 'GRAPH:LCLIP', .true. )
-        call SkewT( trim(fname(2,i)), 20.0, (/240.0, 300.0/),  &
-  &                 draw_region_p, temp, pres, qv, undef=undef, refh=p_ref )
+        call SkewT( trim(fname(2,i)), 30.0, (/245.0, 305.0/),  &
+  &                 draw_region_p, temp, pres, qv, height,  &
+  &                 undef=undef, refh=p_ref, heiopt=.false. )
         if(draw_flag(3:3)=='o')then
            call DclSetParm( 'GRAPH:LCLIP', .false. )
            CALL SGQVPT( vx_new(1), vx_new(2), vy_new(1), vy_new(2) )
