@@ -103,6 +103,9 @@ program sound_conv
      allocate(ww(nz))
      allocate(tmp(nz))
 
+     ew=conv_undef
+     ww=conv_undef
+
 !-- reading file
 
      call read_file_text( trim(iname(id)), nx, nz, cval, skip=skip_num )
@@ -256,8 +259,9 @@ program sound_conv
                  pres(j)=pres(j-1)*exp(-0.5*(g/Rd)*((height(j)-height(j-1))  &
   &                                    *(1.0/temp(j-1)+1.0/temp(j))))
               else if(unity(2)=='PK')then  ! Theta
-                 pres(j)=pres(j-1)*exp((Cpd/Rd)  &
-  &                               *log(1.0-0.5*(g/Cpd)*(height(j)-height(j-1))  &
+                 pres(j)=p0*exp((Cpd/Rd)  &
+  &                            *log(exner_func_dry(pres(j-1))  &
+  &                                -0.5*(g/Cpd)*(height(j)-height(j-1))  &
   &                                    *(1.0/temp(j-1)+1.0/temp(j))))
               end if
            end if
@@ -353,14 +357,14 @@ program sound_conv
      write_flag=.true.
 
      do j=neg_i,nz-1
-        if(height(j)>limit_height)then
-           if(height(j)>0.0.and.pres(j)>0.0)then
+        if(height(j)>=limit_height)then
+           if(height(j)>=0.0.and.pres(j)>0.0)then
               if(write_flag.eqv..true.)then
                  if(conv_inter.eqv..false.)then
                     write(11+id,trim(fomb)) height(j), pres(j), temp(j),  &
   &                                         vapor(j), ew(j), ww(j)
                  else
-                    if(conv_height<height(j))then
+                    if(conv_height<=height(j))then
                        write(11+id,trim(fomb)) height(j), pres(j), temp(j),  &
   &                                            vapor(j), ew(j), ww(j)
                        conv_height=conv_height+dz_conv
