@@ -18,8 +18,8 @@ program matrix_test
   else
      open(unit=10,file='data.dat',status='old')
   end if
-     do i=1,nx
-        read(10,*) (a(i,j),j=1,nx), z(i)
+     do j=1,nx
+        read(10,*) (a(i,j),i=1,nx), z(j)
      end do
   close(unit=10,status='keep')
 
