@@ -8,6 +8,12 @@ module Algebra   ! 黻˹Ԥ⥸塼
   use Basis
 
   public :: rectangle_int
+  public :: abst_2d
+  public :: abst_3d
+  public :: dot_prod_2d
+  public :: dot_prod_3d
+  public :: vec_prod_2d
+  public :: vec_prod_3d
 
 interface rectangle_int
 
@@ -15,6 +21,42 @@ interface rectangle_int
 
 end interface rectangle_int
 
+interface abst_2d
+
+  module procedure abst_2df, abst_2dd
+
+end interface abst_2d
+
+interface abst_3d
+
+  module procedure abst_3df, abst_3dd
+
+end interface abst_3d
+
+interface dot_prod_2d
+
+  module procedure dot_prod_2df, dot_prod_2dd
+
+end interface dot_prod_2d
+
+interface dot_prod_3d
+
+  module procedure dot_prod_3df, dot_prod_3dd
+
+end interface dot_prod_3d
+
+interface vec_prod_2d
+
+  module procedure vec_prod_2df, vec_prod_2dd
+
+end interface vec_prod_2d
+
+interface vec_prod_3d
+
+  module procedure vec_prod_3df, vec_prod_3dd
+
+end interface vec_prod_3d
+
 contains
 
 subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 ʬ
@@ -154,35 +196,25 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 ʬ
   if(i_bot<i_top)then  ! ʬ˳ʻҤ 2 İʾ夢Ȥ
 
      if(present(undeff))then
+        res=res+0.5*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! ü;ûʬ
         do i=i_bot,i_top-1
            if(y(i+1)/=undeff.and.y(i)/=undeff)then
-              if(i==i_bot)then
-                 res=res+0.5*(x(i)-bot)*(y(i)+y_bot)  &
-  &                  +0.5*(x(i+1)-x(i))*(y(i+1)+y(i))
-                     ! ü;̾ûʬ
-              else
-                 res=res+0.5*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
-              end if
+              res=res+0.5*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
            end if
         end do
         res=res+0.5*(top-x(i_top))*(y_top+y(i_top))  ! ü;Τ
      else
+        res=res+0.5*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! ü;ûʬ
         do i=i_bot,i_top-1
-           if(i==i_bot)then
-              res=res+0.5*(x(i)-bot)*(y(i)+y_bot)  &
-  &               +0.5*(x(i+1)-x(i))*(y(i+1)+y(i))
-                  ! ü;̾ûʬ
-           else
-              res=res+0.5*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
-           end if
+           res=res+0.5*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
         end do
         res=res+0.5*(top-x(i_top))*(y_top+y(i_top))  ! ü;Τ
      end if
   else
      if(present(undeff))then
         if(y(i_bot)/=undeff)then
-           res=res+0.5*(x(i)-bot)*(y(i)+y_bot)  &
-  &            +0.5*(top-x(i))*(y_top+y(i))
+           res=res+0.5*(x(i_bot)-bot)*(y(i_bot)+y_bot)  &
+  &            +0.5*(top-x(i_top))*(y_top+y(i_top))
         else
            res=0.5*(top-bot)*(y_top+y_bot)
         end if
@@ -334,35 +366,25 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 ʬ
   if(i_bot<i_top)then  ! ʬ˳ʻҤ 2 İʾ夢Ȥ
 
      if(present(undeff))then
+        res=res+0.5d0*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! ü;ûʬ
         do i=i_bot,i_top-1
            if(y(i+1)/=undeff.and.y(i)/=undeff)then
-              if(i==i_bot)then
-                 res=res+0.5d0*(x(i)-bot)*(y(i)+y_bot)  &
-  &                  +0.5d0*(x(i+1)-x(i))*(y(i+1)+y(i))
-                     ! ü;̾ûʬ
-              else
-                 res=res+0.5d0*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
-              end if
+              res=res+0.5d0*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
            end if
         end do
         res=res+0.5d0*(top-x(i_top))*(y_top+y(i_top))  ! ü;Τ
      else
+        res=res+0.5d0*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! ü;ûʬ
         do i=i_bot,i_top-1
-           if(i==i_bot)then
-              res=res+0.5d0*(x(i)-bot)*(y(i)+y_bot)  &
-  &               +0.5d0*(x(i+1)-x(i))*(y(i+1)+y(i))
-                  ! ü;̾ûʬ
-           else
-              res=res+0.5d0*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
-           end if
+           res=res+0.5d0*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
         end do
         res=res+0.5d0*(top-x(i_top))*(y_top+y(i_top))  ! ü;Τ
      end if
   else
      if(present(undeff))then
         if(y(i_bot)/=undeff)then
-           res=res+0.5d0*(x(i)-bot)*(y(i)+y_bot)  &
-  &            +0.5d0*(top-x(i))*(y_top+y(i))
+           res=res+0.5d0*(x(i_bot)-bot)*(y(i_bot)+y_bot)  &
+  &            +0.5d0*(top-x(i_top))*(y_top+y(i_top))
         else
            res=0.5d0*(top-bot)*(y_top+y_bot)
         end if
@@ -463,7 +485,7 @@ end subroutine rectangle_int_2d
 !------------------------------------------
 !------------------------------------------
 
-subroutine abst_2d(x,y,dis)
+subroutine abst_2df(x,y,dis)
   ! 2 ٥ȥͤ׻롼
   implicit none
   real, intent(in) :: x(:,:)  ! x Υ٥ȥʬ
@@ -476,9 +498,9 @@ subroutine abst_2d(x,y,dis)
 
   if(check_array_size_iflag>0)then
      call check_array_size_dmp_message( check_array_size_2d( nx, ny, y ),  &
-  &                                     "abst_2d" )
+  &                                     "abst_2df" )
      call check_array_size_dmp_message( check_array_size_2d( nx, ny, dis ),  &
-  &                                     "abst_2d" )
+  &                                     "abst_2df" )
   end if
 
   do j=1,ny
@@ -487,12 +509,41 @@ subroutine abst_2d(x,y,dis)
      end do
   end do
 
-end subroutine abst_2d
+end subroutine abst_2df
 
 !------------------------------------------
 !------------------------------------------
 
-subroutine abst_3d(x,y,z,dis)  ! 3 ٥ȥͤ׻롼
+subroutine abst_2dd(x,y,dis)
+  ! 2 ٥ȥͤ׻롼
+  implicit none
+  double precision, intent(in) :: x(:,:)  ! x Υ٥ȥʬ
+  double precision, intent(in) :: y(size(x,1),size(x,2))  ! y Υ٥ȥʬ
+  double precision, intent(inout) :: dis(size(x,1),size(x,2))  ! Ǥͥ٥ȥ
+  integer :: i, j, nx, ny
+
+  nx=size(x,1)
+  ny=size(x,2)
+
+  if(check_array_size_iflag>0)then
+     call check_array_size_dmp_message( check_array_size_2d( nx, ny, y ),  &
+  &                                     "abst_2dd" )
+     call check_array_size_dmp_message( check_array_size_2d( nx, ny, dis ),  &
+  &                                     "abst_2dd" )
+  end if
+
+  do j=1,ny
+     do i=1,nx
+        dis(i,j)=dsqrt(x(i,j)**2+y(i,j)**2)
+     end do
+  end do
+
+end subroutine abst_2dd
+
+!------------------------------------------
+!------------------------------------------
+
+subroutine abst_3df(x,y,z,dis)  ! 3 ٥ȥͤ׻롼
   ! Ĵ뤳Ȥˤ, 2 Ǥη׻ǽ.
   implicit none
   real, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
@@ -507,11 +558,11 @@ subroutine abst_3d(x,y,z,dis)  ! 3 ٥ȥͤ׻롼
 
   if(check_array_size_iflag>0)then
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, y ),  &
-  &                                     "abst_3d" )
+  &                                     "abst_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, z ),  &
-  &                                     "abst_3d" )
+  &                                     "abst_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, dis ),  &
-  &                                     "abst_3d" )
+  &                                     "abst_3df" )
   end if
 
 !$omp parallel default(shared)
@@ -526,7 +577,46 @@ subroutine abst_3d(x,y,z,dis)  ! 3 ٥ȥͤ׻롼
 !$omp end do
 !$omp end parallel
 
-end subroutine abst_3d
+end subroutine abst_3df
+
+!------------------------------------------
+!------------------------------------------
+
+subroutine abst_3dd(x,y,z,dis)  ! 3 ٥ȥͤ׻롼
+  ! Ĵ뤳Ȥˤ, 2 Ǥη׻ǽ.
+  implicit none
+  double precision, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
+  double precision, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
+  double precision, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
+  double precision, intent(inout) :: dis(size(x,1),size(x,2),size(x,3))  ! Ǥͥ٥ȥ
+  integer :: i, j, k, nx, ny, nz
+
+  nx=size(x,1)
+  ny=size(x,2)
+  nz=size(x,3)
+
+  if(check_array_size_iflag>0)then
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, y ),  &
+  &                                     "abst_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, z ),  &
+  &                                     "abst_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, dis ),  &
+  &                                     "abst_3dd" )
+  end if
+
+!$omp parallel default(shared)
+!$omp do schedule(runtime) private(i,j,k)
+  do k=1,nz
+     do j=1,ny
+        do i=1,nx
+           dis(i,j,k)=dsqrt(x(i,j,k)**2+y(i,j,k)**2+z(i,j,k)**2)
+        end do
+     end do
+  end do
+!$omp end do
+!$omp end parallel
+
+end subroutine abst_3dd
 
 !------------------------------------------
 !------------------------------------------
@@ -571,7 +661,7 @@ end subroutine calc_radius
 !------------------------------------------
 !------------------------------------------
 
-subroutine dot_prod_2d(x,y,u,v,dot,undeff)
+subroutine dot_prod_2df(x,y,u,v,dot,undeff)
   ! 2٥ȥѷ׻롼
   ! dot_prod  2 
   implicit none
@@ -588,13 +678,13 @@ subroutine dot_prod_2d(x,y,u,v,dot,undeff)
 
   if(check_array_size_iflag>0)then
      call check_array_size_dmp_message( check_array_size_2d( nx, ny, y ),  &
-  &                                     "dot_prod_2d" )
+  &                                     "dot_prod_2df" )
      call check_array_size_dmp_message( check_array_size_2d( nx, ny, u ),  &
-  &                                     "dot_prod_2d" )
+  &                                     "dot_prod_2df" )
      call check_array_size_dmp_message( check_array_size_2d( nx, ny, v ),  &
-  &                                     "dot_prod_2d" )
+  &                                     "dot_prod_2df" )
      call check_array_size_dmp_message( check_array_size_2d( nx, ny, dot ),  &
-  &                                     "dot_prod_2d" )
+  &                                     "dot_prod_2df" )
   end if
 
   if(present(undeff))then
@@ -620,12 +710,66 @@ subroutine dot_prod_2d(x,y,u,v,dot,undeff)
 
   end if
 
-end subroutine dot_prod_2d
+end subroutine dot_prod_2df
 
 !------------------------------------------
 !------------------------------------------
 
-subroutine dot_prod_3d(x,y,z,u,v,w,dot,undeff)
+subroutine dot_prod_2dd(x,y,u,v,dot,undeff)
+  ! 2٥ȥѷ׻롼
+  ! dot_prod  2 
+  implicit none
+  double precision, intent(in) :: x(:,:)  ! x Υ٥ȥʬ
+  double precision, intent(in) :: y(size(x,1),size(x,2))  ! y Υ٥ȥʬ
+  double precision, intent(in) :: u(size(x,1),size(x,2))  ! x Υ٥ȥʬ
+  double precision, intent(in) :: v(size(x,1),size(x,2))  ! y Υ٥ȥʬ
+  double precision, intent(inout) :: dot(size(x,1),size(x,2))  ! 
+  double precision, intent(in), optional :: undeff        ! ̤
+  integer :: i, j, nx, ny
+
+  nx=size(x,1)
+  ny=size(x,2)
+
+  if(check_array_size_iflag>0)then
+     call check_array_size_dmp_message( check_array_size_2d( nx, ny, y ),  &
+  &                                     "dot_prod_2dd" )
+     call check_array_size_dmp_message( check_array_size_2d( nx, ny, u ),  &
+  &                                     "dot_prod_2dd" )
+     call check_array_size_dmp_message( check_array_size_2d( nx, ny, v ),  &
+  &                                     "dot_prod_2dd" )
+     call check_array_size_dmp_message( check_array_size_2d( nx, ny, dot ),  &
+  &                                     "dot_prod_2dd" )
+  end if
+
+  if(present(undeff))then
+
+     do j=1,ny
+        do i=1,nx
+           if(x(i,j)==undeff.or.u(i,j)==undeff.or.  &
+  &           y(i,j)==undeff.or.v(i,j)==undeff)then
+              dot(i,j)=undeff
+           else
+              dot(i,j)=x(i,j)*u(i,j)+y(i,j)*v(i,j)
+           end if
+        end do
+     end do
+
+  else
+
+     do j=1,ny
+        do i=1,nx
+           dot(i,j)=x(i,j)*u(i,j)+y(i,j)*v(i,j)
+        end do
+     end do
+
+  end if
+
+end subroutine dot_prod_2dd
+
+!------------------------------------------
+!------------------------------------------
+
+subroutine dot_prod_3df(x,y,z,u,v,w,dot,undeff)
   ! 2٥ȥѷ׻롼
   ! פ, 2 ǤѤ׻뤳Ȥǽ
   implicit none
@@ -645,17 +789,17 @@ subroutine dot_prod_3d(x,y,z,u,v,w,dot,undeff)
 
   if(check_array_size_iflag>0)then
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, y ),  &
-  &                                     "dot_prod_3d" )
+  &                                     "dot_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, z ),  &
-  &                                     "dot_prod_3d" )
+  &                                     "dot_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, u ),  &
-  &                                     "dot_prod_3d" )
+  &                                     "dot_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, v ),  &
-  &                                     "dot_prod_3d" )
+  &                                     "dot_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, w ),  &
-  &                                     "dot_prod_3d" )
+  &                                     "dot_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, dot ),  &
-  &                                     "dot_prod_3d" )
+  &                                     "dot_prod_3df" )
   end if
 
   if(present(undeff))then
@@ -692,12 +836,84 @@ subroutine dot_prod_3d(x,y,z,u,v,w,dot,undeff)
 !$omp end parallel
   end if
 
-end subroutine dot_prod_3d
+end subroutine dot_prod_3df
 
 !------------------------------------------
 !------------------------------------------
 
-subroutine vec_prod_2d(x,y,u,v,vecz,undeff)
+subroutine dot_prod_3dd(x,y,z,u,v,w,dot,undeff)
+  ! 2٥ȥѷ׻롼
+  ! פ, 2 ǤѤ׻뤳Ȥǽ
+  implicit none
+  double precision, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
+  double precision, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
+  double precision, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
+  double precision, intent(in) :: u(size(x,1),size(x,2),size(x,3))  ! x Υ٥ȥʬ
+  double precision, intent(in) :: v(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
+  double precision, intent(in) :: w(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
+  double precision, intent(inout) :: dot(size(x,1),size(x,2),size(x,3))  ! 
+  double precision, intent(in), optional :: undeff
+  integer :: i, j, k, nx, ny, nz
+
+  nx=size(x,1)
+  ny=size(x,2)
+  nz=size(x,3)
+
+  if(check_array_size_iflag>0)then
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, y ),  &
+  &                                     "dot_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, z ),  &
+  &                                     "dot_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, u ),  &
+  &                                     "dot_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, v ),  &
+  &                                     "dot_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, w ),  &
+  &                                     "dot_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, dot ),  &
+  &                                     "dot_prod_3dd" )
+  end if
+
+  if(present(undeff))then
+
+!$omp parallel default(shared)
+!$omp do schedule(dynamic) private(i,j,k)
+     do k=1,nz
+        do j=1,ny
+           do i=1,nx
+              if(x(i,j,k)==undeff.or.u(i,j,k)==undeff.or.y(i,j,k)==undeff.or.  &
+  &              v(i,j,k)==undeff.or.z(i,j,k)==undeff.or.w(i,j,k)==undeff)then
+                 dot(i,j,k)=undeff
+              else
+                 dot(i,j,k)=x(i,j,k)*u(i,j,k)+y(i,j,k)*v(i,j,k)+z(i,j,k)*w(i,j,k)
+              end if
+           end do
+        end do
+     end do
+!$omp end do
+!$omp end parallel
+
+  else
+
+!$omp parallel default(shared)
+!$omp do schedule(runtime) private(i,j,k)
+     do k=1,nz
+        do j=1,ny
+           do i=1,nx
+              dot(i,j,k)=x(i,j,k)*u(i,j,k)+y(i,j,k)*v(i,j,k)+z(i,j,k)*w(i,j,k)
+           end do
+        end do
+     end do
+!$omp end do
+!$omp end parallel
+  end if
+
+end subroutine dot_prod_3dd
+
+!------------------------------------------
+!------------------------------------------
+
+subroutine vec_prod_2df(x,y,u,v,vecz,undeff)
   ! 2٥ȥγѷ׻롼
   ! vec_prod  2 
   ! ѤʤΤ, 2 Ƿ׻, Ѥ 1 ʬʤΤ,
@@ -716,13 +932,13 @@ subroutine vec_prod_2d(x,y,u,v,vecz,undeff)
 
   if(check_array_size_iflag>0)then
      call check_array_size_dmp_message( check_array_size_2d( nx, ny, y ),  &
-  &                                     "vec_prod_2d" )
+  &                                     "vec_prod_2df" )
      call check_array_size_dmp_message( check_array_size_2d( nx, ny, u ),  &
-  &                                     "vec_prod_2d" )
+  &                                     "vec_prod_2df" )
      call check_array_size_dmp_message( check_array_size_2d( nx, ny, v ),  &
-  &                                     "vec_prod_2d" )
+  &                                     "vec_prod_2df" )
      call check_array_size_dmp_message( check_array_size_2d( nx, ny, vecz ),  &
-  &                                     "vec_prod_2d" )
+  &                                     "vec_prod_2df" )
   end if
 
   if(present(undeff))then
@@ -748,12 +964,68 @@ subroutine vec_prod_2d(x,y,u,v,vecz,undeff)
 
   end if
 
-end subroutine vec_prod_2d
+end subroutine vec_prod_2df
+
+!-----------------------------------------
+!------------------------------------------
+
+subroutine vec_prod_2dd(x,y,u,v,vecz,undeff)
+  ! 2٥ȥγѷ׻롼
+  ! vec_prod  2 
+  ! ѤʤΤ, 2 Ƿ׻, Ѥ 1 ʬʤΤ,
+  ! intent(inout) ΰ 1 ĤʤȤ.
+  implicit none
+  double precision, intent(in) :: x(:,:)  ! x Υ٥ȥʬ
+  double precision, intent(in) :: y(size(x,1),size(x,2))  ! y Υ٥ȥʬ
+  double precision, intent(in) :: u(size(x,1),size(x,2))  ! x Υ٥ȥʬ
+  double precision, intent(in) :: v(size(x,1),size(x,2))  ! y Υ٥ȥʬ
+  double precision, intent(inout) :: vecz(size(x,1),size(x,2))  ! Ѥľʬ
+  double precision, intent(in), optional :: undeff
+  integer :: i, j, nx, ny
+
+  nx=size(x,1)
+  ny=size(x,2)
+
+  if(check_array_size_iflag>0)then
+     call check_array_size_dmp_message( check_array_size_2d( nx, ny, y ),  &
+  &                                     "vec_prod_2dd" )
+     call check_array_size_dmp_message( check_array_size_2d( nx, ny, u ),  &
+  &                                     "vec_prod_2dd" )
+     call check_array_size_dmp_message( check_array_size_2d( nx, ny, v ),  &
+  &                                     "vec_prod_2dd" )
+     call check_array_size_dmp_message( check_array_size_2d( nx, ny, vecz ),  &
+  &                                     "vec_prod_2dd" )
+  end if
+
+  if(present(undeff))then
+
+        do j=1,ny
+           do i=1,nx
+              if(x(i,j)==undeff.or.u(i,j)==undeff.or.  &
+  &              y(i,j)==undeff.or.v(i,j)==undeff)then
+                 vecz(i,j)=undeff
+              else
+                 vecz(i,j)=x(i,j)*v(i,j)-y(i,j)*u(i,j)
+              end if
+           end do
+        end do
+
+  else
+
+        do j=1,ny
+           do i=1,nx
+              vecz(i,j)=x(i,j)*v(i,j)-y(i,j)*u(i,j)
+           end do
+        end do
+
+  end if
+
+end subroutine vec_prod_2dd
 
 !-----------------------------------------
 !-----------------------------------------
 
-subroutine vec_prod_3d(x,y,z,u,v,w,vecx,vecy,vecz,undeff)
+subroutine vec_prod_3df(x,y,z,u,v,w,vecx,vecy,vecz,undeff)
   ! 2٥ȥγѷ׻롼
   implicit none
   real, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
@@ -774,21 +1046,21 @@ subroutine vec_prod_3d(x,y,z,u,v,w,vecx,vecy,vecz,undeff)
 
   if(check_array_size_iflag>0)then
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, y ),  &
-  &                                     "vec_prod_3d" )
+  &                                     "vec_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, z ),  &
-  &                                     "vec_prod_3d" )
+  &                                     "vec_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, u ),  &
-  &                                     "vec_prod_3d" )
+  &                                     "vec_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, v ),  &
-  &                                     "vec_prod_3d" )
+  &                                     "vec_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, w ),  &
-  &                                     "vec_prod_3d" )
+  &                                     "vec_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, vecx ),  &
-  &                                     "vec_prod_3d" )
+  &                                     "vec_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, vecy ),  &
-  &                                     "vec_prod_3d" )
+  &                                     "vec_prod_3df" )
      call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, vecz ),  &
-  &                                     "vec_prod_3d" )
+  &                                     "vec_prod_3df" )
   end if
 
   if(present(undeff))then
@@ -832,7 +1104,91 @@ subroutine vec_prod_3d(x,y,z,u,v,w,vecx,vecy,vecz,undeff)
 
   end if
 
-end subroutine vec_prod_3d
+end subroutine vec_prod_3df
+
+!-----------------------------------------
+!-----------------------------------------
+
+subroutine vec_prod_3dd(x,y,z,u,v,w,vecx,vecy,vecz,undeff)
+  ! 2٥ȥγѷ׻롼
+  implicit none
+  double precision, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
+  double precision, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
+  double precision, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
+  double precision, intent(in) :: u(size(x,1),size(x,2),size(x,3))  ! x Υ٥ȥʬ
+  double precision, intent(in) :: v(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
+  double precision, intent(in) :: w(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
+  double precision, intent(inout) :: vecx(size(x,1),size(x,2),size(x,3))  ! Ѥ x ʬ
+  double precision, intent(inout) :: vecy(size(x,1),size(x,2),size(x,3))  ! Ѥ y ʬ
+  double precision, intent(inout) :: vecz(size(x,1),size(x,2),size(x,3))  ! Ѥ z ʬ
+  double precision, intent(in), optional :: undeff
+  integer :: i, j, k, nx, ny, nz
+
+  nx=size(x,1)
+  ny=size(x,2)
+  nz=size(x,3)
+
+  if(check_array_size_iflag>0)then
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, y ),  &
+  &                                     "vec_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, z ),  &
+  &                                     "vec_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, u ),  &
+  &                                     "vec_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, v ),  &
+  &                                     "vec_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, w ),  &
+  &                                     "vec_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, vecx ),  &
+  &                                     "vec_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, vecy ),  &
+  &                                     "vec_prod_3dd" )
+     call check_array_size_dmp_message( check_array_size_3d( nx, ny, nz, vecz ),  &
+  &                                     "vec_prod_3dd" )
+  end if
+
+  if(present(undeff))then
+
+!$omp parallel default(shared)
+!$omp do schedule(dynamic) private(i,j,k)
+     do k=1,nz
+        do j=1,ny
+           do i=1,nx
+              if(x(i,j,k)==undeff.or.u(i,j,k)==undeff.or.y(i,j,k)==undeff.or.  &
+  &              v(i,j,k)==undeff.or.z(i,j,k)==undeff.or.w(i,j,k)==undeff)then
+                 vecx(i,j,k)=undeff
+                 vecy(i,j,k)=undeff
+                 vecz(i,j,k)=undeff
+              else
+                 vecx(i,j,k)=y(i,j,k)*w(i,j,k)-z(i,j,k)*v(i,j,k)
+                 vecy(i,j,k)=z(i,j,k)*u(i,j,k)-x(i,j,k)*w(i,j,k)
+                 vecz(i,j,k)=x(i,j,k)*v(i,j,k)-y(i,j,k)*u(i,j,k)
+              end if
+           end do
+        end do
+     end do
+!$omp end do
+!$omp end parallel
+
+  else
+
+!$omp parallel default(shared)
+!$omp do schedule(runtime) private(i,j,k)
+     do k=1,nz
+        do j=1,ny
+           do i=1,nx
+              vecx(i,j,k)=y(i,j,k)*w(i,j,k)-z(i,j,k)*v(i,j,k)
+              vecy(i,j,k)=z(i,j,k)*u(i,j,k)-x(i,j,k)*w(i,j,k)
+              vecz(i,j,k)=x(i,j,k)*v(i,j,k)-y(i,j,k)*u(i,j,k)
+           end do
+        end do
+     end do
+!$omp end do
+!$omp end parallel
+
+  end if
+
+end subroutine vec_prod_3dd
 
 !-----------------------------------------
 !-----------------------------------------
