@@ -8,67 +8,67 @@ interface kaijo
 
   module procedure kaijo_i, kaijo_f
 
-end interface
+end interface kaijo
 
 interface Full_Ellip1_Func
 
   module procedure Full_Ellip1_Func_f, Full_Ellip1_Func_d
 
-end interface
+end interface Full_Ellip1_Func
 
 interface Full_Ellip2_Func
 
   module procedure Full_Ellip2_Func_f, Full_Ellip2_Func_d
 
-end interface
+end interface Full_Ellip2_Func
 
 interface bessj
 
   module procedure bessj_f, bessj_d, bessj_fnoni, bessj_dnoni
 
-end interface
+end interface bessj
 
 interface bessy
 
   module procedure bessy_f, bessy_d, bessy_fnoni, bessy_dnoni
 
-end interface
+end interface bessy
 
 interface sp_bessj
 
   module procedure sp_bessj_f, sp_bessj_d
 
-end interface
+end interface sp_bessj
 
 interface sp_bessy
 
   module procedure sp_bessy_f, sp_bessy_d
 
-end interface
+end interface sp_bessy
 
 interface df_bessj
 
   module procedure df_bessj_f, df_bessj_d, df_bessj_fnoni, df_bessj_dnoni
 
-end interface
+end interface df_bessj
 
 interface df_bessy
 
   module procedure df_bessy_f, df_bessy_d, df_bessy_fnoni, df_bessy_dnoni
 
-end interface
+end interface df_bessy
 
 interface gamma_func
 
   module procedure gamma_func_f, gamma_func_d
 
-end interface
+end interface gamma_func
 
 interface beta_func
 
   module procedure beta_func_f, beta_func_d
 
-end interface
+end interface beta_func
 
 !interface Airy
 
@@ -620,7 +620,7 @@ double precision function bessj_dnoni(nu,t)
 ! $J_{-n}(x)=(-1)^nJ_n(x)$
 ! μΩʤΤ, μξľܷ׻Ԥ褦ѹ.
 ! Lommel ʬϰʲμ
-! $J_{\nu} (x)=\left(\frac{x}{2} \right) ^{\nu} \frac{1}{\sqrt[]{\dble(pi)} \Gamma (\nu +1/2)} \int^{\dble(pi)}_{0}{\cos{(z\cos{\theta} )} } $
+! $J_{\nu} (x)=\left(\frac{x}{2} \right) ^{\nu} \frac{1}{\sqrt[]{\pi_dp} \Gamma (\nu +1/2)} \int^{\pi_dp}_{0}{\cos{(z\cos{\theta} )} } $
 ! , μɾǤΤ, $\nu > -\frac{1}{2} $ޤǤʤΤ, 꾮Υ٥åؿϷ׻Ǥʤ.
 ! , ʲμ٥åؿ
 ! $J_{\nu -1}(x)+J_{\nu +1}(x)=\frac{2\nu}{x} J_{\nu} (x)$
@@ -637,7 +637,7 @@ double precision function bessj_dnoni(nu,t)
   intrinsic :: aint
 
   xmin = 0.0d0
-  xmax = dble(pi)
+  xmax = pi_dp
   dx = (xmax-xmin)/(mmax-1)
 
   if(t<0.0d0)then
@@ -664,7 +664,7 @@ double precision function bessj_dnoni(nu,t)
 
      bessj_dnoni=bessj_dnoni+0.5d0*dx*(cos(t*cos(xmin))*((sin(xmin))**(2.0d0*nu)) &
  &               +cos(t*cos(xmax))*((sin(xmax))**(2.0d0*nu)))
-     bessj_dnoni=bessj_dnoni*((0.5d0*x)**nu)/(sqrt(dble(pi))*gamma_func_d(nu+0.5d0))
+     bessj_dnoni=bessj_dnoni*((0.5d0*x)**nu)/(sqrt(pi_dp)*gamma_func_d(nu+0.5d0))
 
   else  ! nu <= -0.5 ΤȤ.
      bess1=0.0d0
@@ -677,10 +677,10 @@ double precision function bessj_dnoni(nu,t)
 
      bess1=bess1+0.5d0*dx*(cos(t*cos(xmin))*((sin(xmin))**(2.0d0*tmp1)) &
  &               +cos(t*cos(xmax))*((sin(xmax))**(2.0d0*tmp1)))
-     bess1=bess1*((0.5d0*x)**tmp1)/(sqrt(dble(pi))*gamma_func_d(tmp1+0.5))
+     bess1=bess1*((0.5d0*x)**tmp1)/(sqrt(pi_dp)*gamma_func_d(tmp1+0.5))
      bess2=bess2+0.5d0*dx*(cos(t*cos(xmin))*((sin(xmin))**(2.0d0*tmp2)) &
  &               +cos(t*cos(xmax))*((sin(xmax))**(2.0d0*tmp2)))
-     bess2=bess2*((0.5d0*x)**tmp2)/(sqrt(dble(pi))*gamma_func_d(tmp2+0.5d0))
+     bess2=bess2*((0.5d0*x)**tmp2)/(sqrt(pi_dp)*gamma_func_d(tmp2+0.5d0))
 
      tmp=tmp1
 
@@ -817,7 +817,7 @@ double precision function bessy_d( n, z )
   end if
 
   tmin=0.0d0
-  tmax=dble(pi)
+  tmax=pi_dp
   term1=0.0d0
   term2=0.0d0
   dt=1.0d-2
@@ -838,7 +838,7 @@ double precision function bessy_d( n, z )
 
   t=t+dt
   term1=term1+0.5d0*exp(n*t-z*sinh(t))
-  term1=dt*term1/dble(pi)
+  term1=dt*term1/pi_dp
 
 !--  2
 
@@ -850,13 +850,13 @@ double precision function bessy_d( n, z )
   do while (tmp2>thres)
      t=t+dt
      tmp2=exp(-(n*t+z*sinh(t)))
-     term2=term2+tmp2*cos(n*dble(pi))  ! cos μǤͤŪ˲ʤ
+     term2=term2+tmp2*cos(n*pi_dp)  ! cos μǤͤŪ˲ʤ
                                ! 褦, Τߤɾ. cos ϤȤǤ
   end do
 
   t=t+dt
-  term2=term2+0.5d0*exp(-(n*t+z*sinh(t)))*cos(n*dble(pi))
-  term2=dt*term2/dble(pi)
+  term2=term2+0.5d0*exp(-(n*t+z*sinh(t)))*cos(n*pi_dp)
+  term2=dt*term2/pi_dp
 
 !-- ʬ׻
   dt=(tmax-tmin)/nt
@@ -870,7 +870,7 @@ double precision function bessy_d( n, z )
   end do
 
   bessy_d=bessy_d+0.5d0*sin(z*sin(tmax)-n*tmax)
-  bessy_d=dt*bessy_d/dble(pi)-term1-term2
+  bessy_d=dt*bessy_d/pi_dp-term1-term2
 
   return
 end function
@@ -924,8 +924,8 @@ double precision function bessy_dnoni( nu, t )
   end if
 
   if(nu/=aint(nu))then  ! nu ξ, bessy_f ˥쥯Ȥ.
-     bessy_dnoni=(cos(nu*dble(pi))*bessj_dnoni( nu, t )-bessj_dnoni( -nu, t ))  &
-  &              /(sin(nu*dble(pi)))
+     bessy_dnoni=(cos(nu*pi_dp)*bessj_dnoni( nu, t )-bessj_dnoni( -nu, t ))  &
+  &              /(sin(nu*pi_dp))
   else
      bessy_dnoni=bessy_d( int(nu), t )
   end if
@@ -974,7 +974,7 @@ double precision function sp_bessj_d( m, t )
      stop
   end if
 
-  sp_bessj_d=sqrt(0.5d0*dble(pi)/t)*bessj_dnoni( dble(m)+0.5d0, t )
+  sp_bessj_d=sqrt(0.5d0*pi_dp/t)*bessj_dnoni( dble(m)+0.5d0, t )
 
   return
 end function
@@ -1173,7 +1173,7 @@ double precision function df_bessj_dnoni( nu, t )
   intrinsic :: aint
 
   xmin = 0.0d0
-  xmax = dble(pi)
+  xmax = pi_dp
   dx = (xmax-xmin)/(mmax-1)
 
   if(t<0.0d0)then
@@ -1200,7 +1200,7 @@ double precision function df_bessj_dnoni( nu, t )
 
      df_bessj_dnoni=df_bessj_dnoni+0.5d0*dx*(cosh(t*cos(xmin))*((sin(xmin))**(2.0d0*nu)) &
  &               +cosh(t*cos(xmax))*((sin(xmax))**(2.0d0*nu)))
-     df_bessj_dnoni=df_bessj_dnoni*((0.5d0*x)**nu)/(sqrt(dble(pi))*gamma_func_d(nu+0.5d0))
+     df_bessj_dnoni=df_bessj_dnoni*((0.5d0*x)**nu)/(sqrt(pi_dp)*gamma_func_d(nu+0.5d0))
 
   else  ! nu <= -0.5 ΤȤ.
      bess1=0.0d0
@@ -1213,10 +1213,10 @@ double precision function df_bessj_dnoni( nu, t )
 
      bess1=bess1+0.5d0*dx*(cosh(t*cos(xmin))*((sin(xmin))**(2.0d0*tmp1)) &
  &               +cosh(t*cos(xmax))*((sin(xmax))**(2.0d0*tmp1)))
-     bess1=bess1*((0.5d0*x)**tmp1)/(sqrt(dble(pi))*gamma_func_d(tmp1+0.5d0))
+     bess1=bess1*((0.5d0*x)**tmp1)/(sqrt(pi_dp)*gamma_func_d(tmp1+0.5d0))
      bess2=bess2+0.5d0*dx*(cosh(t*cos(xmin))*((sin(xmin))**(2.0d0*tmp2)) &
  &               +cosh(t*cos(xmax))*((sin(xmax))**(2.0d0*tmp2)))
-     bess2=bess2*((0.5d0*x)**tmp2)/(sqrt(dble(pi))*gamma_func_d(tmp2+0.5d0))
+     bess2=bess2*((0.5d0*x)**tmp2)/(sqrt(pi_dp)*gamma_func_d(tmp2+0.5d0))
 
      tmp=tmp1
 
@@ -1539,7 +1539,7 @@ double precision function df_bessy_dnoni( nu, t )
 
   if(nu/=aint(nu))then  ! nu ξ, bessy_f ˥쥯Ȥ.
      df_bessy_dnoni=(df_bessj_dnoni( -nu, t )-df_bessj_dnoni( nu, t ))  &
-  &              /(sin(nu*dble(pi)))
+  &              /(sin(nu*pi_dp))
   else
      df_bessy_dnoni=df_bessy_d( int(nu), t )
   end if
