@@ -91,6 +91,47 @@ subroutine stdio_real( cmod, cpro, rval, unity )
 end subroutine stdio_real
 
 
+subroutine stdio_dble( cmod, cpro, dval, unity )
+! ¿֤³ˤĤ, ͤȼ³֤̾.
+  implicit none
+  character(*), intent(in) :: cmod             ! ⥸塼̾
+  character(*), intent(in) :: cpro             ! ³̾
+  double precision, intent(in) :: dval         ! ³֤
+  character(*), intent(in), optional :: unity  ! ñ
+  character(100) :: formal                     ! ϥեޥå
+  character(20) :: unitc
+  integer :: lengc(3)
+
+  lengc(1)=len_trim(adjustl(cmod))
+  lengc(2)=len_trim(adjustl(cpro))
+
+  if(present(unity))then
+
+     lengc(3)=len_trim(adjustl(unity))
+
+     write(formal,*) lengc(1)+lengc(2)+15
+     write(unitc,*) lengc(3)+3
+
+     formal='(a'//trim(adjustl(formal))//',1P,E14.5,a'//trim(adjustl(unitc))//')'
+
+     write(*,trim(adjustl(formal))) "DEBUG : "//trim(adjustl(cpro))//' in '  &
+  &                        //trim(adjustl(cmod))//' : ', dval,  &
+  &                        ' ['//trim(adjustl(unity))//']'
+
+  else
+
+     write(formal,*) lengc(1)+lengc(2)+15
+
+     formal='(a'//trim(adjustl(formal))//',1P,E14.5)'
+
+     write(*,trim(formal)) "DEBUG : "//trim(adjustl(cpro))//' in '  &
+  &                        //trim(adjustl(cmod))//' : ', dval
+
+  end if
+
+end subroutine stdio_dble
+
+
 subroutine stdio_char( cval, cflag, cmod, cpro )
 ! ³̾ȥ⥸塼̾յʤ, ʸϤԤ.
   implicit none
@@ -188,6 +229,22 @@ subroutine nan_check_s( cmod, cpro, rval )
 end subroutine nan_check_s
 
 
+subroutine nan_check_d( cmod, cpro, dval )
+! ¿֤³ˤĤ, ͤ nan ǤФλݷٹ𤹤.
+  implicit none
+  character(*), intent(in) :: cmod       ! ⥸塼̾
+  character(*), intent(in) :: cpro       ! ³̾
+  double precision, intent(in) :: dval   ! ³֤
+
+!!  if(isnan(dval))then
+  if(dval/=dval)then   ! isnan ؿʤȤθ.
+     call stdio_char( 'Detected NaN value.', 'E',  &
+  &                   cmod=trim(cmod), cpro=trim(cpro) )
+  end if
+
+end subroutine nan_check_d
+
+
 subroutine nan_check_a( cmod, cpro, nx, ny, nz, val )
   ! ¿ val  nan ͤ¸ߤȥ顼Ϥ.
   !  3 Ǥ뤬, ǿ 1 ʤɤꤹ뤳Ȥ,
@@ -272,6 +329,30 @@ subroutine debug_flag_r( dl, cmod, cpro, rval, unity )
 end subroutine debug_flag_r
 
 
+subroutine debug_flag_d( dl, cmod, cpro, dval, unity )
+! ¿顼ѿ֤³ˤĤ, debug level Ȥ˽.
+  implicit none
+  integer, intent(in) :: dl                    ! debug level
+  ! 0 = ⤷ʤ, 1 = NaN ͤäƤȷٹ, 2 = ͤɸ
+  character(*), intent(in) :: cmod             ! ⥸塼̾
+  character(*), intent(in) :: cpro             ! ³̾
+  double precision, intent(in) :: dval         ! ³֤
+  character(*), intent(in), optional :: unity  ! ñ
+
+  select case (dl)
+  case (1)
+     call nan_check_d( trim(cmod), trim(cpro), dval )
+  case (2)
+     if(present(unity))then
+        call stdio_dble( trim(cmod), trim(cpro), dval, trim(unity) )
+     else
+        call stdio_dble( trim(cmod), trim(cpro), dval )
+     end if
+  end select
+
+end subroutine debug_flag_d
+
+
 subroutine debug_flag_a( dl, cmod, cpro, nx, ny, nz, aval )
 ! ¿ѿ֤³ˤĤ, debug level Ȥ˽.
   implicit none
