@@ -191,7 +191,7 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
-real function CAPE( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, opt, dl )
+real function CAPE( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, opt, copt, dl )
 ! ή֥ͭͥ륮 (Convective Available Potential Energy) ׻.
   use Thermo_Const
   implicit none
@@ -201,9 +201,15 @@ real function CAPE( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, opt, dl )
   real, intent(in) :: tmp_t(size(tmp_p))  !  [K]
   real, intent(in) :: z_ref  ! ѡ夲 [m]
   real, intent(in), optional :: undeff
-  integer, intent(in), optional :: opt  ! LNB ׻κݤΥץ (z_LNB )
-  integer, intent(in), optional :: dl  ! ǥХå٥
-  integer :: nx, i, iz_LFC, iz_LNB, option, iundef
+  integer, intent(in), optional :: opt   ! LNB ׻κݤΥץ (z_LNB )
+  integer, intent(in), optional :: copt  ! LFC ͤ, LNB ͤΤʤ,
+                                         ! CAPE ̤ͤˤ뤫ɤ.
+                                         ! ǥե: 1 = ̤ˤ.
+                                         ! 2 = LFC üޤѻ֤ͤ.
+                                         ! , ǡξü LNB ʲ
+                                         ! ǡ.
+  integer, intent(in), optional :: dl    ! ǥХå٥
+  integer :: nx, i, iz_LFC, iz_LNB, option, calc_opt, iundef
   real :: PLFC, TLFC, PLNB, ZLFC, ZLNB
   real :: tmp(size(tmp_p)), t_par(size(tmp_p))
   real :: inv_tmp(size(tmp_p)), inv_p(size(tmp_p))
@@ -226,6 +232,12 @@ real function CAPE( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, opt, dl )
      option=1
   end if
 
+  if(present(copt))then
+     calc_opt=copt
+  else
+     calc_opt=1
+  end if
+
 !-- LFC, LNB Ǥι, , Ϥη׻
 
   TLFC=T_LFC( z_ref, tmp_z, tmp_t, tmp_p, tmp_qv )
@@ -242,8 +254,16 @@ real function CAPE( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, opt, dl )
         iz_LNB=iundef
      end if
   else
-     iz_LFC=iundef
-     iz_LNB=iundef
+     if(ZLFC/=undef.and.calc_opt==2)then
+        call interpo_search_1d( tmp_z, ZLFC, iz_LFC, iundef )
+        if(iz_LFC>=nx)then
+           iz_LFC=iundef
+        end if
+        iz_LNB=nx
+     else
+        iz_LFC=iundef
+        iz_LNB=iundef
+     end if
   end if
 
   if(iz_LFC/=iundef.and.iz_LNB/=iundef)then
@@ -260,19 +280,18 @@ real function CAPE( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, opt, dl )
         call interpolation_1d( (/tmp_z(iz_LNB), tmp_z(iz_LNB+1)/),  &
   &          (/tmp_p(iz_LNB), tmp_p(iz_LNB+1)/), ZLNB, PLNB )
 
-        do i=1,nx
-           if(iz_LFC<=i.and.i<=iz_LNB+1)then
-              if(undef==tmp_t(i))then
-                 tmp(i)=undef
-              else
-                 t_par(i)=moist_laps_temp( PLFC, TLFC, tmp_p(i) )
-                 tmp(i)=(t_par(i)-tmp_t(i))/tmp_p(i)
-              end if
-           else
-              tmp(i)=undef
+        tmp=undef
+        do i=iz_LFC+1,iz_LNB+1
+           if(undef/=tmp_t(i))then
+              t_par(i)=moist_laps_temp( PLFC, TLFC, tmp_p(i) )
+              tmp(i)=(t_par(i)-tmp_t(i))/tmp_p(i)
            end if
         end do
 
+        if(PLFC==tmp_p(iz_LFC))then
+           tmp(iz_LFC)=0.0
+        end if
+
 !-- ʬΤ, ؤ
         do i=1,nx
            inv_tmp(i)=tmp(nx-i+1)
