@@ -200,7 +200,7 @@ real function TP_2_qvs(T,P, opt, dl)  ! ٤˰º׻
 
   if(P<es)then
      TP_2_qvs=10.0
-     write(*,*) "*** WARNING (TP_2_qvs:thermo_function) : es exceeds P.", P, es
+     write(*,*) "*** WARNING (TP_2_qvs:thermo_function) : es exceeds P.", P, es, T
   else
      TP_2_qvs=eps*es/(P-es)
   end if
