@@ -109,7 +109,7 @@ subroutine Forward_Traject_2d( dt, stime, step, ini_x, ini_y,  &
 
   do i=1,step-1
 
-     call interpo_search_1d( t, trajt(i), i_trajt )
+     call interpo_search_1d( t, trajt(i), i_trajt, stdopt=stderr )
 
 !-- ®پ
      if(t(i_trajt)==trajt(i))then
@@ -315,10 +315,10 @@ subroutine Forward_Traject_3d( dt, stime, step, ini_x, ini_y, ini_z,  &
 
   do i=1,step-1
 
-!-- ®پ
-     if(t(i)==trajt(i).or.t(nt)==trajt(i))then
+     call interpo_search_1d( t, trajt(i), i_trajt, stdopt=stderr )
 
-        call interpo_search_1d( t, trajt(i), i_trajt )
+!-- ®پ
+     if(t(i_trajt)==trajt(i))then
 
         if(present(undef))then
            do l=1,nz
@@ -537,7 +537,7 @@ subroutine Backward_Traject_2d( dt, stime, step, ini_x, ini_y,  &
 
   do i=1,step-1
 
-     call interpo_search_1d( r_t, trajt(i), ri_trajt )
+     call interpo_search_1d( r_t, trajt(i), ri_trajt, stdopt=stderr )
                              ! ή֤ trajt ǥ.
      ! --->--->--->--->---> ֤ή --->--->--->--->--->--->
      ! ------ r_t(ri_trajt) ----------- r_t(ri_trajt+1) -------
@@ -760,7 +760,7 @@ subroutine Backward_Traject_3d( dt, stime, step, ini_x, ini_y, ini_z,  &
 !write(*,*) "step check", step
   do i=1,step-1
 
-     call interpo_search_1d( r_t, trajt(i), ri_trajt )
+     call interpo_search_1d( r_t, trajt(i), ri_trajt, stdopt=stderr )
      ! --->--->--->--->---> ֤ή --->--->--->--->--->--->
      ! ------ r_t(ri_trajt) ----------- r_t(ri_trajt+1) -------
      !             |                          |
@@ -977,14 +977,14 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
 !-- ֤
         inter_p=(/trajx(i), trajy(i)/)
 !-- ֤ζ˵ 4 ׻.
-        call interpo_search_2d( x, y, trajx(i), trajy(i), m, n )  
+        call interpo_search_2d( x, y, trajx(i), trajy(i), m, n, stdopt=stderr )
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
         if(m==0.or.n==0.or.m==nx.or.n==ny)then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "*********** WARNING ********"
               write(*,*) "There is no parcel point in the calculating region."
               write(*,*) "Exit!!"
@@ -1002,7 +1002,7 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
   &           v(m,n)==undef.or.v(m,n+1)==undef.or.  &
   &           v(m+1,n)==undef.or.v(m+1,n+1)==undef)then
 
-              if(stderr.eqv..true.)then
+              if(stderr.eqv..false.)then
                  write(*,*) "*********** WARNING ********"
                  write(*,*) "parcel passed the undef point."
                  write(*,*) "Exit!!"
@@ -1024,7 +1024,7 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
         y1=trajy(i)+dt*inter_v(2)
 !-- ׻ traj ΰ¸ߤƤ뤫ǧ
         if(x1<x(1).or.x1>x(nx).or.y1<y(1).or.y1>y(ny))then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "****** WARNING ******"
               write(*,*) "This point does not exist in the region."
               write(*,*) "Exit.!!"
@@ -1045,14 +1045,14 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
         inter_p=(/trajx(i), trajy(i)/)
 
         do id=1,2
-           call interpo_search_2d( x, y, inter_p(1), inter_p(2), m, n )
+           call interpo_search_2d( x, y, inter_p(1), inter_p(2), m, n, stdopt=stderr )
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
            if(m<=0.or.n<=0.or.m==nx.or.n==ny)then
-              if(stderr.eqv..true.)then
+              if(stderr.eqv..false.)then
                  write(*,*) "*********** WARNING ********"
                  write(*,*) "There is no parcel point in the calculating region."
                  write(*,*) "Exit!!"
@@ -1070,7 +1070,7 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
   &              v(m,n)==undef.or.v(m,n+1)==undef.or.  &
   &              v(m+1,n)==undef.or.v(m+1,n+1)==undef)then
 
-                 if(stderr.eqv..true.)then
+                 if(stderr.eqv..false.)then
                     write(*,*) "*********** WARNING ********"
                     write(*,*) "parcel passed the undef point."
                     write(*,*) "Exit!!"
@@ -1107,9 +1107,16 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
            end select
         end do
 
+!-- 嵭롼 (id) 椫 FTF = .true. ǽФƤ, x1, y1, z1 
+!-- ׻ƤʤΤ, Ƚ˹Ԥˤ⤦׻ do 롼 (i) 
+!-- ˽ФƷ׻򽪤餻. 
+        if(FTF.eqv..true.)then
+           exit
+        end if
+
 !-- ׻ traj ΰ¸ߤƤ뤫ǧ
         if(x1<x(1).or.x1>x(nx).or.y1<y(1).or.y1>y(ny))then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "****** WARNING ******"
               write(*,*) "This point does not exist in the region."
               write(*,*) "Exit.!!"
@@ -1131,14 +1138,14 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
         inter_p=(/trajx(i), trajy(i)/)
 
         do id=1,2
-           call interpo_search_2d( x, y, inter_p(1), inter_p(2), m, n )  
+           call interpo_search_2d( x, y, inter_p(1), inter_p(2), m, n, stdopt=stderr )
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
            if(m<=0.or.n<=0.or.m==nx.or.n==ny)then
-              if(stderr.eqv..true.)then
+              if(stderr.eqv..false.)then
                  write(*,*) "*********** WARNING ********"
                  write(*,*) "There is no parcel point in the calculating region."
                  write(*,*) "Exit!!"
@@ -1156,7 +1163,7 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
   &              v(m,n)==undef.or.v(m,n+1)==undef.or.  &
   &              v(m+1,n)==undef.or.v(m+1,n+1)==undef)then
 
-                 if(stderr.eqv..true.)then
+                 if(stderr.eqv..false.)then
                     write(*,*) "*********** WARNING ********"
                     write(*,*) "parcel passed the undef point."
                     write(*,*) "Exit!!"
@@ -1195,7 +1202,7 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
 
 !-- ׻ traj ΰ¸ߤƤ뤫ǧ
         if(x1<x(1).or.x1>x(nx).or.y1<y(1).or.y1>y(ny))then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "****** WARNING ******"
               write(*,*) "This point does not exist in the region."
               write(*,*) "Exit.!!"
@@ -1218,14 +1225,14 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
         inter_p=(/trajx(i), trajy(i)/)
 
         do id=1,3
-           call interpo_search_2d( x, y, inter_p(1), inter_p(2), m, n )  
+           call interpo_search_2d( x, y, inter_p(1), inter_p(2), m, n, stdopt=stderr )
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
            if(m<=0.or.n<=0.or.m==nx.or.n==ny)then
-              if(stderr.eqv..true.)then
+              if(stderr.eqv..false.)then
                  write(*,*) "*********** WARNING ********"
                  write(*,*) "There is no parcel point in the calculating region."
                  write(*,*) "Exit!!"
@@ -1242,7 +1249,7 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
   &              u(m+1,n)==undef.or.u(m+1,n+1)==undef.or.  &
   &              v(m,n)==undef.or.v(m,n+1)==undef.or.  &
   &              v(m+1,n)==undef.or.v(m+1,n+1)==undef)then
-                 if(stderr.eqv..true.)then
+                 if(stderr.eqv..false.)then
                     write(*,*) "*********** WARNING ********"
                     write(*,*) "parcel passed the undef point."
                     write(*,*) "Exit!!"
@@ -1287,9 +1294,16 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
            end select
         end do
 
+!-- 嵭롼 (id) 椫 FTF = .true. ǽФƤ, x1, y1, z1 
+!-- ׻ƤʤΤ, Ƚ˹Ԥˤ⤦׻ do 롼 (i) 
+!-- ˽ФƷ׻򽪤餻. 
+        if(FTF.eqv..true.)then
+           exit
+        end if
+
 !-- ׻ traj ΰ¸ߤƤ뤫ǧ
         if(x1<x(1).or.x1>x(nx).or.y1<y(1).or.y1>y(ny))then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "****** WARNING ******"
               write(*,*) "This point does not exist in the region."
               write(*,*) "Exit.!!"
@@ -1311,14 +1325,14 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
         inter_p=(/trajx(i), trajy(i)/)
 
         do id=1,4
-           call interpo_search_2d( x, y, inter_p(1), inter_p(2), m, n )  
+           call interpo_search_2d( x, y, inter_p(1), inter_p(2), m, n, stdopt=stderr )
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
            if(m<=0.or.n<=0.or.m==nx.or.n==ny)then
-              if(stderr.eqv..true.)then
+              if(stderr.eqv..false.)then
                  write(*,*) "*********** WARNING ********"
                  write(*,*) "There is no parcel point in the calculating region."
                  write(*,*) "Exit!!"
@@ -1335,7 +1349,7 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
   &              u(m+1,n)==undef.or.u(m+1,n+1)==undef.or.  &
   &              v(m,n)==undef.or.v(m,n+1)==undef.or.  &
   &              v(m+1,n)==undef.or.v(m+1,n+1)==undef)then
-                 if(stderr.eqv..true.)then
+                 if(stderr.eqv..false.)then
                     write(*,*) "*********** WARNING ********"
                     write(*,*) "parcel passed the undef point."
                     write(*,*) "Exit!!"
@@ -1388,9 +1402,16 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
            end select
         end do
 
+!-- 嵭롼 (id) 椫 FTF = .true. ǽФƤ, x1, y1, z1 
+!-- ׻ƤʤΤ, Ƚ˹Ԥˤ⤦׻ do 롼 (i) 
+!-- ˽ФƷ׻򽪤餻. 
+        if(FTF.eqv..true.)then
+           exit
+        end if
+
 !-- ׻ traj ΰ¸ߤƤ뤫ǧ
         if(x1<x(1).or.x1>x(nx).or.y1<y(1).or.y1>y(ny))then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "****** WARNING ******"
               write(*,*) "This point does not exist in the region."
               write(*,*) "Exit.!!"
@@ -1496,14 +1517,14 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
 !-- ֤
         inter_p=(/trajx(i), trajy(i), trajz(i)/)
 !-- ֤ζ˵ 4 ׻.
-        call interpo_search_3d( x, y, z, trajx(i), trajy(i), trajz(i), m, n, l )  
+        call interpo_search_3d( x, y, z, trajx(i), trajy(i), trajz(i), m, n, l, stdopt=stderr )
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
         if(m<=0.or.n<=0.or.l<=0.or.m==nx.or.n==ny.or.l==nz)then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "*********** WARNING ********"
               write(*,*) "There is no parcel point in the calculating region."
               write(*,*) "Exit!!"
@@ -1529,7 +1550,7 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
   &           w(m,n+1,l)==undef.or.w(m,n,l+1)==undef.or.  &
   &           w(m+1,n,l)==undef.or.w(m+1,n,l+1)==undef.or.  &
   &           w(m+1,n+1,l)==undef.or.w(m,n+1,l+1)==undef)then
-              if(stderr.eqv..true.)then
+              if(stderr.eqv..false.)then
                  write(*,*) "*********** WARNING ********"
                  write(*,*) "parcel passed the undef point."
                  write(*,*) "Exit!!"
@@ -1555,7 +1576,7 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
         z1=trajz(i)+dt*inter_v(3)
 !-- ׻ traj ΰ¸ߤƤ뤫ǧ
         if(x1<x(1).or.x1>x(nx).or.y1<y(1).or.y1>y(ny).or.z1<z(1).or.z1>z(nz))then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "****** WARNING ******"
               write(*,*) "This point does not exist in the region."
               write(*,*) "Exit.!!"
@@ -1580,14 +1601,14 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
         do id=1,2
            call interpo_search_3d( x, y, z,  &
   &                                inter_p(1), inter_p(2), inter_p(3),  &
-  &                                m, n, l )  
+  &                                m, n, l, stdopt=stderr )
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
            if(m<=0.or.n<=0.or.l<=0.or.m==nx.or.n==ny.or.l==nz)then
-              if(stderr.eqv..true.)then
+              if(stderr.eqv..false.)then
                  write(*,*) "*********** WARNING ********"
                  write(*,*) "There is no parcel point in the calculating region."
                  write(*,*) "Exit!!"
@@ -1613,7 +1634,7 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
   &              w(m,n+1,l)==undef.or.w(m,n,l+1)==undef.or.  &
   &              w(m+1,n,l)==undef.or.w(m+1,n,l+1)==undef.or.  &
   &              w(m+1,n+1,l)==undef.or.w(m,n+1,l+1)==undef)then
-                 if(stderr.eqv..true.)then
+                 if(stderr.eqv..false.)then
                     write(*,*) "*********** WARNING ********"
                     write(*,*) "parcel passed the undef point."
                     write(*,*) "Exit!!"
@@ -1657,9 +1678,16 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
            end select
         end do
 
+!-- 嵭롼 (id) 椫 FTF = .true. ǽФƤ, x1, y1, z1 
+!-- ׻ƤʤΤ, Ƚ˹Ԥˤ⤦׻ do 롼 (i) 
+!-- ˽ФƷ׻򽪤餻. 
+        if(FTF.eqv..true.)then
+           exit
+        end if
+
 !-- ׻ traj ΰ¸ߤƤ뤫ǧ
         if(x1<x(1).or.x1>x(nx).or.y1<y(1).or.y1>y(ny).or.z1<z(1).or.z1>z(nz))then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "****** WARNING ******"
               write(*,*) "This point does not exist in the region."
               write(*,*) "Exit.!!"
@@ -1685,14 +1713,14 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
         do id=1,2
            call interpo_search_3d( x, y, z,  &
   &                                inter_p(1), inter_p(2), inter_p(3),  &
-  &                                m, n, l )  
+  &                                m, n, l, stdopt=stderr )
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
            if(m<=0.or.n<=0.or.l<=0.or.m==nx.or.n==ny.or.l==nz)then
-              if(stderr.eqv..true.)then
+              if(stderr.eqv..false.)then
                  write(*,*) "*********** WARNING ********"
                  write(*,*) "There is no parcel point in the calculating region."
                  write(*,*) "Exit!!"
@@ -1718,7 +1746,7 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
   &              w(m,n+1,l)==undef.or.w(m,n,l+1)==undef.or.  &
   &              w(m+1,n,l)==undef.or.w(m+1,n,l+1)==undef.or.  &
   &              w(m+1,n+1,l)==undef.or.w(m,n+1,l+1)==undef)then
-                 if(stderr.eqv..true.)then
+                 if(stderr.eqv..false.)then
                     write(*,*) "*********** WARNING ********"
                     write(*,*) "parcel passed the undef point."
                     write(*,*) "Exit!!"
@@ -1762,9 +1790,16 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
            end select
         end do
 
+!-- 嵭롼 (id) 椫 FTF = .true. ǽФƤ, x1, y1, z1 
+!-- ׻ƤʤΤ, Ƚ˹Ԥˤ⤦׻ do 롼 (i) 
+!-- ˽ФƷ׻򽪤餻. 
+        if(FTF.eqv..true.)then
+           exit
+        end if
+
 !-- ׻ traj ΰ¸ߤƤ뤫ǧ
         if(x1<x(1).or.x1>x(nx).or.y1<y(1).or.y1>y(ny).or.z1<z(1).or.z1>z(nz))then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "****** WARNING ******"
               write(*,*) "This point does not exist in the region."
               write(*,*) "Exit.!!"
@@ -1791,14 +1826,14 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
         do id=1,3
            call interpo_search_3d( x, y, z,  &
   &                                inter_p(1), inter_p(2), inter_p(3),  &
-  &                                m, n, l )  
+  &                                m, n, l, stdopt=stderr )
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
            if(m<=0.or.n<=0.or.l<=0.or.m==nx.or.n==ny.or.l==nz)then
-              if(stderr.eqv..true.)then
+              if(stderr.eqv..false.)then
                  write(*,*) "*********** WARNING ********"
                  write(*,*) "There is no parcel point in the calculating region."
                  write(*,*) "Exit!!"
@@ -1824,7 +1859,7 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
   &              w(m,n+1,l)==undef.or.w(m,n,l+1)==undef.or.  &
   &              w(m+1,n,l)==undef.or.w(m+1,n,l+1)==undef.or.  &
   &              w(m+1,n+1,l)==undef.or.w(m,n+1,l+1)==undef)then
-                 if(stderr.eqv..true.)then
+                 if(stderr.eqv..false.)then
                     write(*,*) "*********** WARNING ********"
                     write(*,*) "parcel passed the undef point."
                     write(*,*) "Exit!!"
@@ -1878,9 +1913,16 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
            end select
         end do
 
+!-- 嵭롼 (id) 椫 FTF = .true. ǽФƤ, x1, y1, z1 
+!-- ׻ƤʤΤ, Ƚ˹Ԥˤ⤦׻ do 롼 (i) 
+!-- ˽ФƷ׻򽪤餻. 
+        if(FTF.eqv..true.)then
+           exit
+        end if
+
 !-- ׻ traj ΰ¸ߤƤ뤫ǧ
         if(x1<x(1).or.x1>x(nx).or.y1<y(1).or.y1>y(ny).or.z1<z(1).or.z1>z(nz))then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "****** WARNING ******"
               write(*,*) "This point does not exist in the region."
               write(*,*) "Exit.!!"
@@ -1900,20 +1942,21 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
 
 
   case ('RK4')
+
      do i=1,step-1
         inter_p=(/trajx(i), trajy(i), trajz(i)/)
 
         do id=1,4
            call interpo_search_3d( x, y, z,  &
   &                                inter_p(1), inter_p(2), inter_p(3),  &
-  &                                m, n, l )  
+  &                                m, n, l, stdopt=stderr )
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
            if(m<=0.or.n<=0.or.l<=0.or.m==nx.or.n==ny.or.l==nz)then
-              if(stderr.eqv..true.)then
+              if(stderr.eqv..false.)then
                  write(*,*) "*********** WARNING ********"
                  write(*,*) "There is no parcel point in the calculating region."
                  write(*,*) "Exit!!"
@@ -1939,7 +1982,7 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
   &              w(m,n+1,l)==undef.or.w(m,n,l+1)==undef.or.  &
   &              w(m+1,n,l)==undef.or.w(m+1,n,l+1)==undef.or.  &
   &              w(m+1,n+1,l)==undef.or.w(m,n+1,l+1)==undef)then
-                 if(stderr.eqv..true.)then
+                 if(stderr.eqv..false.)then
                     write(*,*) "*********** WARNING ********"
                     write(*,*) "parcel passed the undef point."
                     write(*,*) "Exit!!"
@@ -2003,9 +2046,16 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
            end select
         end do
 
+!-- 嵭롼 (id) 椫 FTF = .true. ǽФƤ, x1, y1, z1 
+!-- ׻ƤʤΤ, Ƚ˹Ԥˤ⤦׻ do 롼 (i) 
+!-- ˽ФƷ׻򽪤餻. 
+        if(FTF.eqv..true.)then
+           exit
+        end if
+
 !-- ׻ traj ΰ¸ߤƤ뤫ǧ
         if(x1<x(1).or.x1>x(nx).or.y1<y(1).or.y1>y(ny).or.z1<z(1).or.z1>z(nz))then
-           if(stderr.eqv..true.)then
+           if(stderr.eqv..false.)then
               write(*,*) "****** WARNING ******"
               write(*,*) "This point does not exist in the region."
               write(*,*) "Exit.!!"
